pilas.actores.mono

Package pilas :: Package actores :: Module mono |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.mono

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10  import pilas
    11
    12 -class Mono(Actor):
    13      """Representa la cara de un mono de color marrón.
    14
    15      .. image:: images/actores/mono.png
    16
    17      Este personaje se usa como ejemplo básico de un actor. Por
    18      ejemplo, esta es una forma de usar al actor:
    19
    20          >>> mono = pilas.actores.Mono()
    21          >>> mono.decir("Hola!!!")
    22          >>> mono.gritar()
    23      """
    24
    25 -    def __init__(self, x=0, y=0):
    26          """
    27          Constructor del Mono.
    28
    29          :param x: posicion horizontal del mono.
    30          :type x: int
    31          :param y: posicion vertical del mono.
    32          :type y: int
    33
    34          """
    35          self.image_normal = pilas.imagenes.cargar('monkey_normal.png')
    36          self.image_smile = pilas.imagenes.cargar('monkey_smile.png')
    37          self.image_shout = pilas.imagenes.cargar('monkey_shout.png')
    38
    39          self.sound_shout = pilas.sonidos.cargar('shout.wav')
    40          self.sound_smile = pilas.sonidos.cargar('smile.wav')
    41
    42          # Inicializa el actor.
    43          Actor.__init__(self, self.image_normal, x=x, y=y)
    44          self.radio_de_colision = 50
    45
    46 -    def sonreir(self):
    47          """Hace que el mono sonria y emita un sonido."""
    48          self.definir_imagen(self.image_smile)
    49          # Luego de un segundo regresa a la normalidad
    50          pilas.mundo.agregar_tarea_una_vez(2, self.normal)
    51          self.sound_smile.reproducir()
    52
    53 -    def gritar(self):
    54          """Hace que el mono grite emitiendo un sonido."""
    55          self.definir_imagen(self.image_shout)
    56          # Luego de un segundo regresa a la normalidad
    57          pilas.mundo.agregar_tarea_una_vez(1, self.normal)
    58          self.sound_shout.reproducir()
    59
    60 -    def normal(self):
    61          """Restaura la expresión del mono.
    62
    63          Este función se suele ejecutar por si misma, unos
    64          segundos después de haber gritado y sonreir."""
    65          self.definir_imagen(self.image_normal)
    66
    67 -    def decir(self, mensaje):
    68          """Emite un mensaje y además sonrie mientras habla.
    69
    70          :param mensaje: Texto que se desea mostrar.
    71          :type mensaje: string
    72
    73          Por ejemplo:
    74
    75              >>> mono.decir("Estoy hablando!!!")
    76
    77          .. image:: images/actores/mono_dice.png
    78          """
    79          self.sonreir()
    80          Actor.decir(self, mensaje)
    81
    82 -    def saltar(self):
    83          """ Hace que el mono sonria y salte. """
    84          self.sonreir()
    85          self.hacer(pilas.comportamientos.Saltar())
    86